netapp_ontap.models.volume_analytics_scan_throttle_reason API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_analytics_scan_throttle_reason`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeAnalyticsScanThrottleReasonSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeAnalyticsScanThrottleReason object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `arguments: List[str] GET POST PATCH`

    Arguments present in the warning message encountered.

  `code: str GET`

    Warning code indicating why scanner throttling is reported.

    Example: 6739881

  `message: str GET`

    A message that provides details for scan throttling.

    Example: The file system analytics scan running on volume "fsavol2" in SVM "vs2" has slowed down on node "my_node". Reason: Computing resources are being used by higher priority workloads.